pub struct IntCone { /* private fields */ }Expand description
Integer cone operations.
Implementations
Sourceimpl IntCone
impl IntCone
Sourcepub fn from_hilbert_basis(generators: Vec<IntVector>) -> Self
pub fn from_hilbert_basis(generators: Vec<IntVector>) -> Self
Create a new integer cone from its Hilbert basis.
Sourcepub fn generators(&self) -> &[IntVector] ⓘ
pub fn generators(&self) -> &[IntVector] ⓘ
Get the generators.
Sourcepub fn contains_int(&self, point: &IntVector) -> bool
pub fn contains_int(&self, point: &IntVector) -> bool
Check if a point is in the integer cone.