pub struct ArbitraryFloatContext {
pub precision: Precision,
pub rounding: RoundingMode,
}Expand description
Context for arbitrary precision operations.
Provides a convenient way to perform multiple operations with the same precision and rounding mode.
Fields
precision: PrecisionDefault precision for operations.
rounding: RoundingModeDefault rounding mode.
Implementations
Sourceimpl ArbitraryFloatContext
impl ArbitraryFloatContext
Sourcepub fn new(precision: Precision, rounding: RoundingMode) -> Self
pub fn new(precision: Precision, rounding: RoundingMode) -> Self
Create a new context with the given precision and rounding mode.
Sourcepub fn zero(&self) -> ArbitraryFloat
pub fn zero(&self) -> ArbitraryFloat
Create a zero value.
Sourcepub fn one(&self) -> ArbitraryFloat
pub fn one(&self) -> ArbitraryFloat
Create a one value.
Sourcepub fn from_f64(&self, value: f64) -> ArbitraryFloat
pub fn from_f64(&self, value: f64) -> ArbitraryFloat
Create from f64.
Sourcepub fn add(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
pub fn add(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
Add two values.
Sourcepub fn sub(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
pub fn sub(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
Subtract two values.
Sourcepub fn mul(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
pub fn mul(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
Multiply two values.
Sourcepub fn div(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
pub fn div(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat
Divide two values.
Sourcepub fn sqrt(&self, a: &ArbitraryFloat) -> ArbitraryFloat
pub fn sqrt(&self, a: &ArbitraryFloat) -> ArbitraryFloat
Compute square root.