Row

Struct Row 

pub struct Row {
    pub basic_var: VarId,
    pub constant: BigRational,
    pub coeffs: FxHashMap<VarId, BigRational>,
}
A row in the simplex tableau represents: basic_var = constant + sum(coeff_i * nonbasic_var_i).

Fields

basic_var: VarId

The basic variable for this row.

constant: BigRational

The constant term.

coeffs: FxHashMap<VarId, BigRational>

Coefficients for non-basic variables: var_id -> coefficient.

Implementations

Source

impl Row

pub fn new(basic_var: VarId) -> Self

Create a new row with a basic variable.

pub fn from_expr( basic_var: VarId, constant: BigRational, coeffs: FxHashMap<VarId, BigRational>, ) -> Self

Create a row representing: basic_var = constant + sum(coeffs).

pub fn eval( &self, non_basic_values: &FxHashMap<VarId, BigRational>, ) -> BigRational

Get the value of the basic variable given values of non-basic variables.

pub fn add_row(&mut self, multiplier: &BigRational, other: &Row)

Add a multiple of another row to this row. self += multiplier * other

pub fn scale(&mut self, scalar: &BigRational)

Multiply the row by a scalar.

pub fn substitute(&mut self, var: VarId, row: &Row)

Substitute a non-basic variable using another row. If var appears in this row, replace it using: var = row.constant + sum(row.coeffs).

pub fn is_valid(&self, basic_vars: &FxHashSet<VarId>) -> bool

Check if the row is valid (no basic variable in RHS).

pub fn normalize(&mut self)

Normalize the row by dividing by the GCD of coefficients.