pub struct RustBlas { /* private fields */ }Expand description
Pure Rust implementation of BLAS operations.
This implementation provides exact rational arithmetic operations, ensuring correctness for linear programming solvers that require exact solutions.
Implementations
Sourceimpl RustBlas
impl RustBlas
Sourcepub fn with_config(config: BlasConfig) -> Self
pub fn with_config(config: BlasConfig) -> Self
Creates a new RustBlas instance with custom configuration.