ArbitraryFloatContext

Struct ArbitraryFloatContext 

pub struct ArbitraryFloatContext {
    pub precision: Precision,
    pub rounding: RoundingMode,
}
Context for arbitrary precision operations.

Provides a convenient way to perform multiple operations with the same precision and rounding mode.

Fields

precision: Precision

Default precision for operations.

rounding: RoundingMode

Default rounding mode.

Implementations

Source

impl ArbitraryFloatContext

pub fn new(precision: Precision, rounding: RoundingMode) -> Self

Create a new context with the given precision and rounding mode.

pub fn zero(&self) -> ArbitraryFloat

Create a zero value.

pub fn one(&self) -> ArbitraryFloat

Create a one value.

pub fn from_f64(&self, value: f64) -> ArbitraryFloat

Create from f64.

pub fn add(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat

Add two values.

pub fn sub(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat

Subtract two values.

pub fn mul(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat

Multiply two values.

pub fn div(&self, a: &ArbitraryFloat, b: &ArbitraryFloat) -> ArbitraryFloat

Divide two values.

pub fn sqrt(&self, a: &ArbitraryFloat) -> ArbitraryFloat

Compute square root.