pub struct Precision { /* private fields */ }Expand description
Precision specification for arbitrary precision floats.
Specifies the number of bits in the mantissa (significand). Higher precision means more accurate results but slower computation.
Implementations